#ifndef CUBEJSONPLUGIN_H
#define CUBEJSONPLUGIN_H

#include "CubePlugin.h"
#include "PluginServices.h"
#include "TabInterface.h"
#include "TreeItem.h"
#include <QWidget>
#include <QVBoxLayout>
#include <QLabel>
#include <QPushButton>
#include <QJsonObject>
#include <QFileDialog>
#include <QObject>

/**
 * @brief CubeJsonPlugin class: A Cube plugin that visualizes system tree data and allows exporting selected items to JSON.
 * Derives from CubePlugin (context-sensitive plugin) and TabInterface to add a tab to the CubeGUI.
 */
class CubeJsonPlugin : public QObject, public cubepluginapi::CubePlugin, public cubegui::TabInterface {
    Q_OBJECT
    Q_INTERFACES(cubepluginapi::CubePlugin)
    Q_PLUGIN_METADATA(IID "CubeJsonPlugin") // Unique plugin identifier

public:
    CubeJsonPlugin();

    // CubePlugin implementation
    /**
     * @brief Initializes the plugin when a cube file is opened. Sets up the GUI components.
     * @param service Pointer to PluginServices for interacting with CubeGUI.
     * @return True if the plugin is successfully started; false otherwise.
     */
    bool cubeOpened(cubepluginapi::PluginServices* service) override;

    /**
     * @brief Cleans up resources when the cube file is closed or the plugin is deactivated.
     */
    void cubeClosed() override;

    /**
     * @brief Returns the name of the plugin.
     * @return Plugin name as a QString.
     */
    QString name() const override;

    /**
     * @brief Provides the version number of the plugin.
     * @param major Major version.
     * @param minor Minor version.
     * @param bugfix Bugfix version.
     */
    void version(int& major, int& minor, int& bugfix) const override;

    /**
     * @brief Returns the help text describing the plugin's functionality.
     * @return Help text as a QString.
     */
    QString getHelpText() const override;

    // TabInterface implementation
    /**
     * @brief Returns the label for the tab added by this plugin.
     * @return Tab label as a QString.
     */
    QString label() const override;

    /**
     * @brief Returns the widget that will be placed inside the tab.
     * @return Pointer to the QWidget.
     */
    QWidget* widget() override;

private slots:
    /**
     * @brief Slot called when a tree item is selected. Updates the label to show the selected item's name.
     * @param item Pointer to the selected tree item.
     */
    void treeItemIsSelected(cubepluginapi::TreeItem* item);

    /**
     * @brief Slot called when the Export button is clicked. Exports the selected item's name to a JSON file.
     */
    void exportJson();

private:
    QWidget* widget_; // Main widget for the plugin tab
    QLabel* label_; // Label to display the selected item's name
    QPushButton* exportButton_; // Button to export selected item's data to JSON
    cubepluginapi::PluginServices* service_; // Pointer to Cube's PluginServices
    QString selectedItemName_; // Name of the currently selected tree item
};

#endif // CUBEJSONPLUGIN_H